import { Image, Text, View, ScrollView } from '@tarojs/components';
import React, { useCallback, useEffect, useLayoutEffect, useState } from 'react';
import Taro from '@tarojs/taro';
import styles from './index.module.scss';
import Avator from '@root/components/Avator';
import Welcome from './components/welcome';
import { fetchProjectList } from './service';
import Page from '@root/components/Page';

export default function ProjectListView() {
  const [projectList, setProjectList] = useState([]);

  const fetchList = useCallback(async () => {
    const dataList = await fetchProjectList();
    setProjectList(dataList);
  }, []);

  useEffect(() => {
    fetchList();
  }, [fetchList])

  return (
    <Page wrapperClassName={styles.page}>
      <ScrollView className={styles.project} scrollY>
        <View className={styles.wrapPadding}>
          <Avator className={styles.avator} onClick={() => Taro.navigateTo({ url: '/pages/usercenter/index' })}  />
        </View>
        <Welcome className={[styles.wrapPadding, styles.mt10]} />
        <View className={[styles.listTitle, styles.wrapPadding]}>
          <Text>我的项目</Text>
        </View>
        {
          projectList.map(project => (
            <View className={styles.projectItem} key={project.id}>
              <Image className={styles.img} src={project.showImgUrl} />
              <View className={styles.label}>
                <Text>{project.projName}</Text>
              </View>
            </View>
          ))
        }
      </ScrollView>
    </Page>
  )
}



